@@ -15,16 +15,15 @@ use crate::driver::Action;
 pub struct Read;
 
 impl Action<Read> {
-    pub(crate) fn read(fd: RawFd, len: u32) -> io::Result<Action<Read>> {
+    pub fn read(fd: RawFd, len: u32) -> io::Result<Action<Read>> {
         let entry = opcode::Read::new(types::Fd(fd), ptr::null_mut(), len)
             .buf_group(0)
             .build()
             .flags(Flags::BUFFER_SELECT);
-
         Action::submit(Read, entry)
     }
 
-    pub(crate) fn poll_read(&mut self, cx: &mut Context<'_>) -> Poll<io::Result<ProvidedBuf>> {
+    pub fn poll_read(&mut self, cx: &mut Context) -> Poll<io::Result<ProvidedBuf>> {
         let completion = ready!(Pin::new(&mut *self).poll(cx));
         let n = completion.result?;
         let bid = buffer_select(completion.flags).expect("buffer_select unimplemented");
@@ -35,7 +34,6 @@ impl Action<Read> {
             provided_buf.set_len(n as usize);
             provided_buf
         };
-
         Poll::Ready(Ok(buf))
     }
 }
